//$Id: bmp-saver.h,v 1.3 2005/11/24 21:54:51 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_IO_BMP_SAVER_H
#define GUIKACHU_IO_BMP_SAVER_H

#include "io/io.h"
#include <gdkmm/pixbuf.h>

namespace Guikachu
{
    namespace IO
    {
        void save_bmp (const Glib::RefPtr<Gdk::Pixbuf> &pixbuf,
                       unsigned char *&data, filesize_t &len) throw (Glib::Exception);
    }
}

#endif /* !GUIKACHU_IO_BMP_SAVER_H */
